@@ -1,4 +1,4 @@
-from sdccli.cli.formatter.text_formatter import alert, dashboard
+from sdccli.cli.formatter.text_formatter import alert, dashboard, panel
 from sdccli.cli.formatter.text_formatter.scanning import alert as scanning_alert
 from sdccli.cli.formatter.text_formatter.scanning import image
 
@@ -10,6 +10,7 @@ class NormalFormatter:
         self.formats.update(dashboard.formats())
         self.formats.update(scanning_alert.formats())
         self.formats.update(image.formats())
+        self.formats.update(panel.formats())
 
     def format(self, response, format_type):
         if format_type in self.formats:
