@@ -5,7 +5,6 @@ from sdcclient import SdSecureClient, SdScanningClient, SdSecureClientV1
 from sdcclient import SdMonitorClient as SdMonitorClientV2
 from sdccli.client_v3.monitor import SdMonitorClient
 
-
 from sdccli.cli.formatter.json_formatter import JsonFormatter
 from sdccli.cli.formatter.text_formatter import NormalFormatter
 
@@ -90,6 +89,9 @@ class Config(object):
             self.secure['url'] = secure_url
         self.secure['ssl_verify'] = not self.secure.get('disable_ssl_verification', False)
 
+        self.monitor['url'] = self.monitor['url'].rstrip('/')
+        self.secure['url'] = self.secure['url'].rstrip('/')
+
         if not (self.monitor['ssl_verify'] and self.secure['ssl_verify']):
             # suppress the InsecureRequestWarning when non tls connections are created
             import urllib3
