@@ -33,6 +33,18 @@ def dashboards(file_data, sdmonitor, existing_dashboards, restore_unowned):
 
         dashboard['id'] = None
         dashboard['version'] = None
+
+        # We need to update the team IDs in case the old ones have been removed
+        if dashboard.get("teamName") is not None:
+            ok, res = sdmonitor.get_team(dashboard.get("teamName"))
+            if ok:
+                dashboard["teamId"] = res["id"]
+        for setting in dashboard["sharingSettings"]:
+            if setting["member"]["name"] != None:
+                ok, res = sdmonitor.get_team(setting["member"]["name"])
+                if ok:
+                    setting["member"]["id"] = res["id"]
+
         ok, result = sdmonitor.create_dashboard_with_configuration(dashboard)
         if not ok:
             errors.append("couldn't recreate dashboard " + name + ': ' + result)
